==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/en_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Today",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Tasks" : "Tasks",
    "The Tasks app for Nextcloud" : "The Tasks app for Nextcloud",
    "New List" : "New List",
    "Cancel" : "Cancel",
    "Save" : "Save",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "Edit" : "Edit",
    "Download" : "Download",
    "Delete" : "Delete",
    "Unshare" : "Unshare",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Change sort order" : "Change sort order",
    "Start date" : "Start date",
    "Due date" : "Due date",
    "Last modified" : "Last modified",
    "Priority" : "Priority",
    "Alphabetically" : "Alphabetically",
    "Manually" : "Manually",
    "Task is completed" : "Task is completed",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Tomorrow" : "Tomorrow",
    "Set start date" : "Set start date",
    "Set due date" : "Set due date",
    "All day" : "All day",
    "Task not found!" : "Task not found!",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/en_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Today",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Tasks" : "Tasks",
    "The Tasks app for Nextcloud" : "The Tasks app for Nextcloud",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Share with users or groups" : "Share with users or groups",
    "Can edit" : "Can edit",
    "Edit" : "Edit",
    "Copy private link" : "Copy private link",
    "Copied" : "Copied",
    "Export" : "Export",
    "Delete" : "Delete",
    "Unshare" : "Unshare",
    "Save" : "Save",
    "Calendar link copied to clipboard." : "Calendar link copied to clipboard.",
    "Calendar link could not be copied to clipboard." : "Calendar link could not be copied to clipboard.",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "An error occurred, unable to delete the calendar." : "An error occurred, unable to delete the calendar.",
    "Name" : "Surname",
    "Deleted" : "Deleted",
    "Restore" : "Restore",
    "Delete permanently" : "Delete permanently",
    "Empty trash bin" : "Empty trash bin",
    "Change sort order" : "Change sort order",
    "Start date" : "Start date",
    "Due date" : "Due date",
    "Last modified" : "Last modified",
    "Priority" : "Priority",
    "Alphabetically" : "Alphabetically",
    "Manually" : "Manually",
    "Task is completed" : "Task is completed",
    "Cancel" : "Cancel",
    "Close" : "Close",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Tomorrow" : "Tomorrow",
    "New List" : "New List",
    "All day" : "All day",
    "Details" : "Details",
    "Select tags" : "Select tags",
    "Notes" : "Notes",
    "Reminders" : "Reminders",
    "Repeat" : "Repeat",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Task not found!" : "Task not found!",
    "Set start date" : "Set start date",
    "Set due date" : "Set due date"
},
"nplurals=2; plural=(n != 1);");
